'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var constants = require('../common/constants.js');
var httpClient = require('./http-client.js');

const errors = {
  SessionError: 'SessionError',
  NotLoggedInError: 'NotLoggedInError'
};
const isObject = data => typeof data === 'object' && data !== null;
const isError = data => isObject(data) && typeof data['name'] === 'string' && data['name'] in errors;
const handleError = async result => {
  return isError(result) ? Promise.reject(result) : result;
};
class RestApi {
  token;
  httpClient;
  errorHandler;

  get cookie() {
    return `connect.sid=${this.token}`;
  }

  constructor(token, httpClient$1 = new httpClient.DefaultHttpClient(), errorHandler = handleError) {
    this.token = token;
    this.httpClient = httpClient$1;
    this.errorHandler = errorHandler;
  }

  async getPage(projectName, pageName) {
    return this.get(`${constants.constants.rest.baseUrl}/pages/${encodeURIComponent(projectName)}/${encodeURIComponent(pageName)}?followRename=true`);
  }

  async getProject(projectName) {
    return this.get(`${constants.constants.rest.baseUrl}/projects/${encodeURIComponent(projectName)}`);
  }

  async getProjects() {
    return this.get(`${constants.constants.rest.baseUrl}/projects`);
  }

  async getMe() {
    return this.get(`${constants.constants.rest.baseUrl}/users/me`);
  }

  async replaceLinks(projectName, data) {
    return this.#post(`${constants.constants.rest.baseUrl}/pages/${encodeURIComponent(projectName)}/replace/links`, data);
  }

  async get(url) {
    return this.httpClient.get(url, {
      headers: {
        Cookie: this.cookie
      }
    }).then(this.errorHandler);
  } // TODO(feat): resolve CSRF error


  async #post(url, data) {
    return this.httpClient.post(url, JSON.stringify(data), {
      headers: {
        Cookie: this.cookie
      }
    }).then(this.errorHandler);
  }

}

exports.RestApi = RestApi;
exports.handleError = handleError;
exports.isError = isError;
exports.isObject = isObject;
//# sourceMappingURL=rest-api.js.map
