'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const isString = value => typeof value === 'string';
const pairwise = array => {
  return array.map((value, index) => index === 0 ? [null, value] : [array[index - 1], value]);
}; // @deprecated

const threewise = array => {
  return array.map((value, index) => {
    const previous = index === 0 ? null : array[index - 1];
    const next = index === array.length - 1 ? null : array[index + 1];
    return [previous, value, next];
  });
};
const threewiseMap = (array, project) => {
  const mapped = [];

  for (let i = 0; i < array.length; i++) {
    const prev = mapped[i - 1];
    const curr = array[i];
    const next = array[i + 1];
    mapped.push(project(curr, prev, next, i));
  }

  return mapped;
};
const extractTags = nodes => {
  if (nodes == undefined) {
    return [];
  } else if (typeof nodes === 'string') {
    return [];
  } else if (Array.isArray(nodes)) {
    return nodes.flatMap(extractTags);
  } else if (nodes.type === 'indent') {
    return extractTags(nodes.children);
  } else if (nodes.type === 'hashTag') {
    return [nodes.unit.content]; // hash stripped
  } else {
    return [];
  }
};
const extractLinks = nodes => {
  if (nodes == undefined) {
    return [];
  } else if (typeof nodes === 'string') {
    return [];
  } else if (Array.isArray(nodes)) {
    return nodes.flatMap(extractLinks);
  } else if (nodes.type === 'indent') {
    return extractLinks(nodes.children);
  } else if (nodes.type === 'link') {
    return [nodes.unit.content]; // [] stripped
  } else {
    return [];
  }
};
const extractTexts = nodes => {
  if (nodes == undefined) {
    return [];
  } else if (typeof nodes === 'string') {
    return [nodes];
  } else if (Array.isArray(nodes)) {
    return nodes.flatMap(extractTexts);
  } else if (nodes.type === 'indent') {
    return extractTexts(nodes.children);
  } else {
    return [];
  }
};

exports.extractLinks = extractLinks;
exports.extractTags = extractTags;
exports.extractTexts = extractTexts;
exports.isString = isString;
exports.pairwise = pairwise;
exports.threewise = threewise;
exports.threewiseMap = threewiseMap;
//# sourceMappingURL=functions.js.map
