import { constants } from '../common/constants.js';
import { DefaultHttpClient } from './http-client.js';

const errors = {
    SessionError: 'SessionError',
    NotLoggedInError: 'NotLoggedInError',
};
const isObject = (data) => typeof data === 'object' && data !== null;
const isError = (data) => isObject(data) && typeof data['name'] === 'string' && data['name'] in errors;
const handleError = async (result) => {
    return isError(result) ? Promise.reject(result) : result;
};
class RestApi {
    token;
    httpClient;
    errorHandler;
    get cookie() {
        return `connect.sid=${this.token}`;
    }
    constructor(token, httpClient = new DefaultHttpClient(), errorHandler = handleError) {
        this.token = token;
        this.httpClient = httpClient;
        this.errorHandler = errorHandler;
    }
    async getPage(projectName, pageName) {
        return this.get(`${constants.rest.baseUrl}/pages/${encodeURIComponent(projectName)}/${encodeURIComponent(pageName)}?followRename=true`);
    }
    async getProject(projectName) {
        return this.get(`${constants.rest.baseUrl}/projects/${encodeURIComponent(projectName)}`);
    }
    async getProjects() {
        return this.get(`${constants.rest.baseUrl}/projects`);
    }
    async getMe() {
        return this.get(`${constants.rest.baseUrl}/users/me`);
    }
    async replaceLinks(projectName, data) {
        return this.#post(`${constants.rest.baseUrl}/pages/${encodeURIComponent(projectName)}/replace/links`, data);
    }
    async get(url) {
        return this.httpClient.get(url, { headers: { Cookie: this.cookie } }).then(this.errorHandler);
    }
    // TODO(feat): resolve CSRF error
    async #post(url, data) {
        return this.httpClient.post(url, JSON.stringify(data), { headers: { Cookie: this.cookie } }).then(this.errorHandler);
    }
}

export { RestApi, handleError, isError, isObject };
//# sourceMappingURL=rest-api.js.map
